Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5496)

Unified Diff: chrome/browser/android/vr_shell/color_scheme.h

Issue 2914623003: [VrShell] Centralize color handling and enable close button on fullscreen (Closed)
Patch Set: clean up after rebase Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/android/vr_shell/color_scheme.h
diff --git a/chrome/browser/android/vr_shell/color_scheme.h b/chrome/browser/android/vr_shell/color_scheme.h
index ebbed05f57c648c06addb7ec75c328016008560a..7754c9b34b3cfbbf19b89f5c36e66cd3e500a626 100644
--- a/chrome/browser/android/vr_shell/color_scheme.h
+++ b/chrome/browser/android/vr_shell/color_scheme.h
@@ -21,21 +21,38 @@ struct ColorScheme {
// These colors should be named generically, if possible, so that they can be
// meaningfully reused by multiple elements.
- SkColor horizon;
+ SkColor world_background;
SkColor floor;
SkColor ceiling;
SkColor floor_grid;
// The foreground color is used for text and sometimes for icons.
- SkColor foreground;
- SkColor emphasized;
- SkColor deemphasized;
+ SkColor element_foreground;
cjgrant 2017/06/05 17:57:08 Should live with other element_ members below, and
amp 2017/06/05 21:40:58 Done. I moved the text (now url) colors down with
+ SkColor text_emphasized;
+ SkColor text_deemphasized;
- // This is the background color. To be used behind text in the foreground
- // color. The related hover and down colors are to be used for buttons.
- SkColor background;
- SkColor background_hover;
- SkColor background_down;
+ // This is the element background color. To be used behind text or icons in
+ // the foreground color. The related hover and down colors are to be used for
+ // buttons.
+ SkColor element_background;
+ SkColor element_background_hover;
+ SkColor element_background_down;
+
+ // Specific element background and foregrounds
+ SkColor close_button_foreground;
+ SkColor close_button_background;
+ SkColor close_button_background_hover;
+ SkColor close_button_background_down;
+ SkColor loading_indicator_background;
+ SkColor loading_indicator_foreground;
+ SkColor exit_warning_background;
+ SkColor exit_warning_foreground;
+ SkColor transient_warning_background;
+ SkColor transient_warning_foreground;
+ SkColor permanent_warning_background;
+ SkColor permanent_warning_foreground;
+ SkColor system_indicator_background;
+ SkColor system_indicator_foreground;
// If you have a segmented element, its separators should use this color.
SkColor separator;
@@ -49,9 +66,9 @@ struct ColorScheme {
// The color used for disabled icons.
SkColor disabled;
- // Colors used for the loading progress bar indicator.
- SkColor loading_background;
- SkColor loading_foreground;
+ // Screen dimmer colors.
+ SkColor dimmer_outer;
+ SkColor dimmer_inner;
};
} // namespace vr_shell
« no previous file with comments | « no previous file | chrome/browser/android/vr_shell/color_scheme.cc » ('j') | chrome/browser/android/vr_shell/color_scheme.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698